@@ -1,13 +1,14 @@
 /* Function prototypes
- *  
- * Copyright (C) 2000 Shawn Betts
- * 
- * This program is free software; you can redistribute it and/or modify
+ * Copyright (C) 2000, 2001 Shawn Betts
+ *
+ * This file is part of ratpoison.
+ *
+ * ratpoison is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * ratpoison is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -15,10 +16,11 @@
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA */
+ * Boston, MA 02111-1307 USA
+ */
 
-#ifndef _EVENTS_H
-#define _EVENTS_H
+#ifndef _RATPOISON_EVENTS_H
+#define _RATPOISON_EVENTS_H 1
 
 void handle_events ();
 void delegate_event (XEvent *ev);
@@ -26,4 +28,4 @@ void key_press (XEvent *ev);
 void map_request (XEvent *ev);
 void unmap_notify (XEvent *ev);
 
-#endif _EVENTS_H
+#endif /* _RATPOISON_EVENTS_H */
