@@ -1,12 +1,14 @@
-/* 
- * Copyright (C) 2000 Shawn Betts
- * 
- * This program is free software; you can redistribute it and/or modify
+/* Ratpoison.
+ * Copyright (C) 2000, 2001 Shawn Betts
+ *
+ * This file is part of ratpoison.
+ *
+ * ratpoison is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * ratpoison is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -14,7 +16,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA */
+ * Boston, MA 02111-1307 USA
+ */
 
 #include <X11/X.h>
 #include <X11/Xlib.h>
@@ -22,11 +25,13 @@
 #include <X11/Xatom.h>
 #include <X11/Xproto.h>
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
 #include <unistd.h>
 #include <getopt.h>
+#include <string.h>
 
 #include "ratpoison.h"
 
@@ -56,6 +61,10 @@ static XFontStruct *font;
 
 char **myargv;
 
+XGCValues gv;
+
+struct rp_key prefix_key;
+
 /* Command line options */
 static struct option ratpoison_longopts[] = { {"help", no_argument, 0, 'h'},
 					      {"version", no_argument, 0, 'v'},
@@ -65,7 +74,33 @@ static struct option ratpoison_longopts[] = { {"help", no_argument, 0, 'h'},
 static char ratpoison_opts[] = "hvrk";
 
 void
-sighandler ()
+fatal (const char *msg)
+{
+  fprintf (stderr, "ratpoison: %s", msg);
+  abort ();
+}
+
+void *
+xmalloc (size_t size)
+{
+  register void *value = malloc (size);
+  if (value == 0)
+    fatal ("Virtual memory exhausted");
+  return value;
+}
+
+void *
+xrealloc (void *ptr, size_t size)
+{
+  register void *value = realloc (ptr, size);
+  if (value == 0)
+    fatal ("Virtual memory exhausted");
+  PRINT_DEBUG("realloc: %d\n", size);
+  return value;
+}
+
+void
+sighandler (int signum)
 {
   fprintf (stderr, "ratpoison: Agg! I've been SHOT!\n"); 
   clean_up ();
@@ -73,48 +108,7 @@ sighandler ()
 }
 
 void
-send_restart ()
-{
-  XEvent ev;
-  int status;
-
-  ev.xclient.type = ClientMessage;
-  ev.xclient.window = DefaultRootWindow (dpy);
-  ev.xclient.message_type = rp_restart;
-  ev.xclient.format = 32;
-  ev.xclient.data.l[0] = rp_restart;
-  ev.xclient.data.l[1] = CurrentTime;
-
-  status = XSendEvent (dpy, DefaultRootWindow (dpy), False, SubstructureRedirectMask, &ev); 
-  if (status == 0)
-    {
-      PRINT_ERROR ("failed to send restart event\n");
-    }
-}
-
-void
-send_kill ()
-{
-  XEvent ev;
-  int status;
-
-  ev.xclient.type = ClientMessage;
-  ev.xclient.window = DefaultRootWindow (dpy);
-  ev.xclient.message_type = rp_kill;
-  ev.xclient.format = 32;
-  ev.xclient.data.l[0] = rp_kill;
-  ev.xclient.data.l[1] = CurrentTime;
-
-  status = XSendEvent (dpy, DefaultRootWindow (dpy), False, SubstructureRedirectMask, &ev); 
-  if (status == 0)
-    {
-      PRINT_ERROR ("failed to send kill event\n");
-    }
-}
-
-
-void
-hup_handler ()
+hup_handler (int signum)
 {
   /* Doesn't function correctly. The event IS placed on the queue but
      XSync() doesn't seem to sync it and until other events come in
@@ -126,7 +120,7 @@ hup_handler ()
 }
 
 void
-alrm_handler ()
+alrm_handler (int signum)
 {
   int i;
 
@@ -152,17 +146,52 @@ handler (Display *d, XErrorEvent *e)
 
   if (ignore_badwindow && e->error_code == BadWindow) return 0;
 
-  XGetErrorText (d, e->error_code, error_msg, sizeof (error_msg));
+  strcpy (error_msg, "ERROR: ");
+
+  XGetErrorText (d, e->error_code, error_msg + 7, sizeof (error_msg) - 7);
   fprintf (stderr, "ratpoison: %s!\n", error_msg);
 
-  exit (EXIT_FAILURE); 
+  marked_message (error_msg, 0, strlen (error_msg));
+
+/*   exit (EXIT_FAILURE);  */
+  return 0;
+}
+
+void
+set_sig_handler (int sig, void (*action)(int))
+{
+  /* use sigaction because SVR4 systems do not replace the signal
+    handler by default which is a tip of the hat to some god-aweful
+    ancient code.  So use the POSIX sigaction call instead. */
+  struct sigaction act;
+       
+  /* check setting for sig */
+  if (sigaction (sig, NULL, &act)) 
+    {
+      PRINT_ERROR ("Error %d fetching SIGALRM handler\n", errno );
+    } 
+  else 
+    {
+      /* if the existing action is to ignore then leave it intact
+	 otherwise add our handler */
+      if (act.sa_handler != SIG_IGN) 
+	{
+	  act.sa_handler = action;
+	  sigemptyset(&act.sa_mask);
+	  act.sa_flags = 0;
+	  if (sigaction (sig, &act, NULL)) 
+	    {
+	      PRINT_ERROR ("Error %d setting SIGALRM handler\n", errno );
+	    }
+	}
+    }
 }
 
 void
 print_version ()
 {
   printf ("%s %s\n", PACKAGE, VERSION);
-  printf ("Copyright (C) 2000 Shawn Betts\n\n");
+  printf ("Copyright (C) 2000, 2001 Shawn Betts\n\n");
 
   exit (EXIT_SUCCESS);
 }  
@@ -181,6 +210,91 @@ print_help ()
   exit (EXIT_SUCCESS);
 }
 
+void
+read_rc_file (FILE *file)
+{
+  size_t n = 256;
+  char *partial;
+  char *line;
+  int linesize = n;
+
+  partial = (char*)xmalloc(n);
+  line = (char*)xmalloc(linesize);
+
+  *line = '\0';
+  while (fgets (partial, n, file) != NULL)
+    {
+      if ((strlen (line) + strlen (partial)) <= linesize)
+	{
+	  linesize *= 2;
+	  line = (char*) xrealloc (line, linesize);
+	}
+
+      strcat (line, partial);
+
+      if (feof(file) || (*(line + strlen(line) - 1) == '\n'))
+	{
+	  /* FIXME: this is a hack, command() should properly parse
+	     the command and args (ie strip whitespace, etc) 
+
+	     We should not care if there is a newline (or vertical
+	     tabs or linefeeds for that matter) at the end of the
+	     command (or anywhere between tokens). */
+	  if (*(line + strlen(line) - 1) == '\n')
+	    *(line + strlen(line) - 1) = '\0';
+
+	  PRINT_DEBUG ("rcfile line: %s\n", line);
+
+	  /* do it */
+	  command (line);
+
+	  *line = '\0';
+	}
+    }
+
+
+  free (line);
+  free (partial);
+}
+
+static void
+read_startup_files ()
+{
+  char *homedir;
+  FILE *fileptr;
+
+  /* first check $HOME/.ratpoisonrc and if that does not exist then try
+     /etc/ratpoisonrc */
+
+  homedir = getenv ("HOME");
+  if (!homedir)
+    fprintf (stderr, "ratpoison: $HOME not set!?\n");
+  else
+    {
+      char *filename = (char*)xmalloc (strlen (homedir) + strlen ("/.ratpoisonrc") + 1);
+      sprintf (filename, "%s/.ratpoisonrc", homedir);
+      
+      if ((fileptr = fopen (filename, "r")) == NULL)
+	{
+	  /* we probably don't need to report this, its not an error */
+	  fprintf (stderr, "ratpoison: could not open %s\n", filename);
+
+	  if ((fileptr = fopen ("/etc/ratpoisonrc", "r")) == NULL)
+	    {
+	      /* neither is this */
+	      fprintf (stderr, "ratpoison: could not open /etc/ratpoisonrc\n");
+	    }
+	}
+
+      if (fileptr)
+	{
+	  read_rc_file (fileptr);
+	  fclose (fileptr);
+	}
+
+      free (filename);
+    }
+}
 
 int
 main (int argc, char *argv[])
@@ -227,10 +341,10 @@ main (int argc, char *argv[])
 
   /* Setup signal handlers. */
   XSetErrorHandler(handler);  
-  if (signal (SIGALRM, alrm_handler) == SIG_IGN) signal (SIGALRM, SIG_IGN);
-  if (signal (SIGTERM, sighandler) == SIG_IGN) signal (SIGTERM, SIG_IGN);
-  if (signal (SIGINT, sighandler) == SIG_IGN) signal (SIGINT, SIG_IGN);
-  if (signal (SIGHUP, hup_handler) == SIG_IGN) signal (SIGHUP, SIG_IGN);
+  set_sig_handler (SIGALRM, alrm_handler);
+  set_sig_handler (SIGTERM, sighandler);
+  set_sig_handler (SIGINT, sighandler);
+  set_sig_handler (SIGHUP, hup_handler);
 
   /* Set ratpoison specific Atoms. */
   rp_restart = XInternAtom (dpy, "RP_RESTART", False);
@@ -261,20 +375,17 @@ main (int argc, char *argv[])
 
   init_numbers ();
   init_window_list ();
+  initialize_default_keybindings ();
 
-  font = XLoadQueryFont (dpy, FONT_NAME);
+  font = XLoadQueryFont (dpy, FONT);
   if (font == NULL)
     {
-      fprintf (stderr, "ratpoison: Cannot load font %s.\n", FONT_NAME);
+      fprintf (stderr, "ratpoison: Cannot load font %s.\n", FONT);
       exit (EXIT_FAILURE);
     }
 
   num_screens = ScreenCount (dpy);
-  if ((screens = (screen_info *)malloc (sizeof (screen_info) * num_screens)) == NULL)
-    {
-      PRINT_ERROR ("Out of memory!\n");
-      exit (EXIT_FAILURE);
-    }  
+  screens = (screen_info *)xmalloc (sizeof (screen_info) * num_screens);
 
   PRINT_DEBUG ("%d screens.\n", num_screens);
 
@@ -284,9 +395,10 @@ main (int argc, char *argv[])
       init_screen (&screens[i], i);
     }
 
+  read_startup_files ();
+
   /* Set an initial window as active. */
-  rp_current_window = rp_window_head;
-  set_active_window (rp_current_window);
+  set_active_window (find_window_other ());
   
   handle_events ();
 
@@ -296,8 +408,7 @@ main (int argc, char *argv[])
 static void
 init_screen (screen_info *s, int screen_num)
 {
-  XColor fg_color, bg_color, bold_color, junk;
-  XGCValues gv;
+  XColor fg_color, bg_color,/*  bold_color, */ junk;
 
   s->screen_num = screen_num;
   s->root = RootWindow (dpy, screen_num);
@@ -306,20 +417,20 @@ init_screen (screen_info *s, int screen_num)
   XGetWindowAttributes (dpy, s->root, &s->root_attr);
 
   /* Get our program bar colors */
-  if (!XAllocNamedColor (dpy, s->def_cmap, BAR_FG_COLOR, &fg_color, &junk))
+  if (!XAllocNamedColor (dpy, s->def_cmap, FOREGROUND, &fg_color, &junk))
     {
-      fprintf (stderr, "ratpoison: Unknown color '%s'\n", BAR_FG_COLOR);
+      fprintf (stderr, "ratpoison: Unknown color '%s'\n", FOREGROUND);
     }
 
-  if (!XAllocNamedColor (dpy, s->def_cmap, BAR_BG_COLOR, &bg_color, &junk))
+  if (!XAllocNamedColor (dpy, s->def_cmap, BACKGROUND, &bg_color, &junk))
     {
-      fprintf (stderr, "ratpoison: Unknown color '%s'\n", BAR_BG_COLOR);
+      fprintf (stderr, "ratpoison: Unknown color '%s'\n", BACKGROUND);
     }
 
-  if (!XAllocNamedColor (dpy, s->def_cmap, BAR_BOLD_COLOR, &bold_color, &junk))
-    {
-      fprintf (stderr, "ratpoison: Unknown color '%s'\n", BAR_BOLD_COLOR);
-    }
+/*   if (!XAllocNamedColor (dpy, s->def_cmap, BAR_BOLD_COLOR, &bold_color, &junk)) */
+/*     { */
+/*       fprintf (stderr, "ratpoison: Unknown color '%s'\n", BAR_BOLD_COLOR); */
+/*     } */
 
   /* Setup the GC for drawing the font. */
   gv.foreground = fg_color.pixel;
@@ -332,11 +443,11 @@ init_screen (screen_info *s, int screen_num)
 			   GCForeground | GCBackground | GCFunction 
 			   | GCLineWidth | GCSubwindowMode | GCFont, 
 			   &gv);
-  gv.foreground = bold_color.pixel;
-  s->bold_gc = XCreateGC(dpy, s->root, 
-			 GCForeground | GCBackground | GCFunction 
-			 | GCLineWidth | GCSubwindowMode | GCFont, 
-			 &gv);
+/*   gv.foreground = bold_color.pixel; */
+/*   s->bold_gc = XCreateGC(dpy, s->root,  */
+/* 			 GCForeground | GCBackground | GCFunction  */
+/* 			 | GCLineWidth | GCSubwindowMode | GCFont,  */
+/* 			 &gv); */
 
   XSelectInput(dpy, s->root,
                PropertyChangeMask | ColormapChangeMask
@@ -381,5 +492,5 @@ find_screen (Window w)
   for (i=0; i<num_screens; i++)
     if (screens[i].root == w) return &screens[i];
 
-  return NULL;
-}
+   return NULL;
+ }
