@@ -1,13 +1,14 @@
 /* Standard header for ratpoison.
- *  
- * Copyright (C) 2000 Shawn Betts
- * 
- * This program is free software; you can redistribute it and/or modify
+ * Copyright (C) 2000, 2001 Shawn Betts
+ *
+ * This file is part of ratpoison.
+ *
+ * ratpoison is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * ratpoison is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -15,10 +16,11 @@
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307 USA */
+ * Boston, MA 02111-1307 USA
+ */
 
 #ifndef _RATPOISON_H
-#define _RATPOISON_H
+#define _RATPOISON_H 1
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -26,6 +28,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <X11/Xlib.h>
 
 /* Some error reporting macros */
 #define PRE_PRINT_LOCATION fprintf (stderr, "%s:%s():%d: ", __FILE__, __FUNCTION__, __LINE__);
@@ -40,6 +43,8 @@
 #  define PRINT_DEBUG(format, args...) 
 #endif /* DEBUG */
 
+extern XGCValues gv;
+
 #include "conf.h"
 
 #include "data.h"
@@ -49,8 +54,17 @@
 #include "events.h"
 #include "number.h"
 #include "input.h"
+#include "messages.h"
+#include "communications.h"
+#include "sbuf.h"
 
 void clean_up ();
 screen_info *find_screen (Window w);
 
-#endif /* _RATPOISON_H */
+void read_rc_file (FILE *file);
+
+void fatal (const char *msg);
+void *xmalloc (size_t size);
+void *xrealloc (void *ptr, size_t size);
+
+#endif /* ! _RATPOISON_H */
